@@ -4,11 +4,9 @@ from pathlib import Path
 from subprocess import Popen
 from argparse import ArgumentParser, RawTextHelpFormatter
 import concurrent.futures
-import subprocess
 import glob2
 import time
 import json
-import sys
 import os
 import re
 
@@ -128,8 +126,18 @@ def parse_arguments():
         help="by default duplicated files are deleted."
     )
 
+    parser.add_argument(
+        "--version",
+        action="store_true",
+        help="prints the version"
+    )
+
     args = parser.parse_args()
 
+    if args.version:
+        print('compile-commands: 1.1.2')
+        exit(0)
+
     if not args.dir and not args.file:
         print("error: must specified at least --file or --dir")
         exit(2)
